#!/bin/sh
# $Id
#

install_wcslib()
{
#
# CG: WCSLIB requires the directory $DESTPWD/bin to exist, therefore
#     I create all of them: bin, lib and include
mkdir -p $DESTPWD/bin $DESTPWD/lib $DESTPWD/include

cd $THISPWD/tmp
if [ -f ../${WCSLIB}.tar.gz ];then 
  if [ -d ${WCSLIB} ]; then
    rm -rf ${WCSLIB}.old
    mv ${WCSLIB}  ${WCSLIB}.old
  fi
  gunzip -c ../${WCSLIB}.tar.gz | tar xf -
  cd ${WCSLIB}
  if ! ./configure --prefix=$DESTPWD ; then
    return 1
  fi
  if ! make all; then
    return 1
  fi
  if ! make install; then
    return 1
  fi
  cp wcsconfig.h $DESTPWD/include/${WCSLIB}
else
  echo "Error: Package ${WCSLIB}.tar.gz not found"
  return 1
fi
WCSDIR=$DESTPWD; export WCSDIR
echo "WCS installation finished"
return 0
}

install_cpl()
{
cd $THISPWD/tmp
if [ -f ../${CPL}.tar.gz ];then 
  if [ -d ${CPL} ]; then
    rm -rf ${CPL}.old
    mv  ${CPL} ${CPL}.old
  fi
  gunzip -c ../${CPL}.tar.gz  | tar xf -
  if [ -z "$CFITSIODIR" -o ! -d "$CFITSIODIR" ]; then
    echo "Error: CFITSIODIR not defined or directory does not exist"
    return 1
  fi
  if [ -z "$WCSDIR" -o ! -d "$WCSDIR" ]; then
    echo "Error: WCSDIR not defined or directory does not exist"
    return 1
  fi
  if [ -z "$FFTWDIR" -o ! -d "$FFTWDIR" ]; then
    echo "Error: FFTWDIR not defined or directory does not exist"
    return 1
  fi
  if [ -z "$JAVA_HOME" -o ! -d "$JAVA_HOME" ]; then
    echo "Error: JAVA_HOME not defined or directory does not exist"
    return 1
  fi
  cd ${CPL}
  CXXFLAGS="-g -O0"; export CXXFLAGS
  CFLAGS="-g -O0 -fno-builtin -fno-common"; export CFLAGS
  if ! ./configure --prefix=$DESTPWD \
  --with-java=${JAVA_HOME} \
  --with-cfitsio=${CFITSIODIR} \
  --with-wcs=${WCSDIR} \
  --with-fftw=${FFTWDIR} \
  CPPFLAGS=-DCX_DISABLE_ASSERT ; then
    return 1
  fi
  if ! make install ; then
    return 1
  fi
  unset CXXFLAGS
  unset CFLAGS
else
  echo "Error: Package ${CPL}.tar.gz not found"
  return 1
fi
CPLDIR=$DESTPWD; export CPLDIR
echo "CPL installation finished"
return 0
}

# Main, main, MAIN

CPL=cpl-6.3.1
WCSLIB=wcslib-4.16
if [ ! -z "$GNU_ROOT" ]; then
  export CFITSIODIR=$GNU_ROOT
  export FFTWDIR=$GNU_ROOT
fi

THISPWD=`dirname $0`
THISPWD=`(cd $THISPWD ; /bin/pwd)`
if [ -z $INTROOT ]; then 
  echo "Error: INTROOT not defined"
  exit 1
elif [ ! -d $INTROOT ]; then
  echo "Error: INTROOT=$INTROOT not such directory"
  exit 1
fi

DESTPWD=${INTROOT}/cpl
#echo FFTWDIR=$FFTWDIR
#echo CFITSIODIR=$CFITSIODIR
#echo WCSDIR=$WCSDIR

cd $THISPWD
rm -rf $DESTPWD tmp
mkdir -p $DESTPWD tmp

cmd=`basename $0`

if ! install_wcslib ; then
  echo "Error installing WCSLIB. Exit"
  exit 1
fi

if ! install_cpl ; then
  echo "Error installing CPL. Exit"
  exit 1
fi

exit 0
